"""Auto-generated model profiles.

DO NOT EDIT THIS FILE MANUALLY.
This file is generated by the langchain-profiles CLI tool.

It contains data derived from the models.dev project.

Source: https://github.com/sst/models.dev
License: MIT License

To update these data, refer to the instructions here:

https://docs.langchain.com/oss/python/langchain/models#updating-or-overwriting-profile-data
"""

from typing import Any

_PROFILES: dict[str, dict[str, Any]] = {
    "featherless/qwerky-72b": {
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "allenai/molmo-2-8b:free": {
        "max_input_tokens": 36864,
        "max_output_tokens": 36864,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
    },
    "nvidia/nemotron-nano-9b-v2:free": {
        "max_input_tokens": 128000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "nvidia/nemotron-nano-12b-v2-vl:free": {
        "max_input_tokens": 128000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "nvidia/nemotron-3-nano-30b-a3b:free": {
        "max_input_tokens": 256000,
        "max_output_tokens": 256000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "nvidia/nemotron-nano-9b-v2": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "arcee-ai/trinity-large-preview:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "arcee-ai/trinity-mini:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "xiaomi/mimo-v2-flash": {
        "max_input_tokens": 262144,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "microsoft/mai-ds-r1:free": {
        "max_input_tokens": 163840,
        "max_output_tokens": 163840,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "sarvamai/sarvam-m:free": {
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "liquid/lfm-2.5-1.2b-thinking:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
    },
    "liquid/lfm-2.5-1.2b-instruct:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "thudm/glm-z1-32b:free": {
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "sourceful/riverflow-v2-fast-preview": {
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "sourceful/riverflow-v2-max-preview": {
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "sourceful/riverflow-v2-standard-preview": {
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": False,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "rekaai/reka-flash-3": {
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "stepfun/step-3.5-flash:free": {
        "max_input_tokens": 256000,
        "max_output_tokens": 256000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "stepfun/step-3.5-flash": {
        "max_input_tokens": 256000,
        "max_output_tokens": 256000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "cognitivecomputations/dolphin3.0-r1-mistral-24b": {
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "cognitivecomputations/dolphin3.0-mistral-24b": {
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "cognitivecomputations/dolphin-mistral-24b-venice-edition:free": {
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "kwaipilot/kat-coder-pro:free": {
        "max_input_tokens": 256000,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "deepseek/deepseek-v3.1-terminus:exacto": {
        "max_input_tokens": 131072,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "deepseek/deepseek-r1-0528:free": {
        "max_input_tokens": 163840,
        "max_output_tokens": 163840,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
    },
    "deepseek/deepseek-r1-distill-qwen-14b": {
        "max_input_tokens": 64000,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
    },
    "deepseek/deepseek-r1:free": {
        "max_input_tokens": 163840,
        "max_output_tokens": 163840,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "deepseek/deepseek-r1-0528-qwen3-8b:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "deepseek/deepseek-v3.2-speciale": {
        "max_input_tokens": 163840,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "deepseek/deepseek-chat-v3.1": {
        "max_input_tokens": 163840,
        "max_output_tokens": 163840,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "deepseek/deepseek-chat-v3-0324": {
        "max_input_tokens": 16384,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "deepseek/deepseek-r1-distill-llama-70b": {
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
    },
    "deepseek/deepseek-v3.1-terminus": {
        "max_input_tokens": 131072,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "deepseek/deepseek-v3.2": {
        "max_input_tokens": 163840,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "deepseek/deepseek-v3-base:free": {
        "max_input_tokens": 163840,
        "max_output_tokens": 163840,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "openrouter/sherlock-think-alpha": {
        "max_input_tokens": 1840000,
        "max_output_tokens": 0,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openrouter/sherlock-dash-alpha": {
        "max_input_tokens": 1840000,
        "max_output_tokens": 0,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "moonshotai/kimi-dev-72b:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "moonshotai/kimi-k2": {
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "moonshotai/kimi-k2-0905": {
        "max_input_tokens": 262144,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "moonshotai/kimi-k2-0905:exacto": {
        "max_input_tokens": 262144,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "moonshotai/kimi-k2.5": {
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "moonshotai/kimi-k2-thinking": {
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "moonshotai/kimi-k2:free": {
        "max_input_tokens": 32800,
        "max_output_tokens": 32800,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "google/gemini-2.5-flash-lite-preview-09-2025": {
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "google/gemini-2.5-pro-preview-06-05": {
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "google/gemma-3n-e4b-it:free": {
        "max_input_tokens": 8192,
        "max_output_tokens": 2000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "google/gemini-2.5-flash-preview-09-2025": {
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "google/gemini-2.5-pro-preview-05-06": {
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "google/gemma-3n-e2b-it:free": {
        "max_input_tokens": 8192,
        "max_output_tokens": 2000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "google/gemini-2.5-flash": {
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "google/gemini-2.0-flash-001": {
        "max_input_tokens": 1048576,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "google/gemini-3-flash-preview": {
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "google/gemma-3-12b-it:free": {
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "google/gemini-2.5-flash-lite": {
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "google/gemini-2.0-flash-exp:free": {
        "max_input_tokens": 1048576,
        "max_output_tokens": 1048576,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "google/gemma-2-9b-it": {
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "google/gemma-3-4b-it:free": {
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "google/gemma-3n-e4b-it": {
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "google/gemini-3-pro-preview": {
        "max_input_tokens": 1050000,
        "max_output_tokens": 66000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "google/gemma-3-12b-it": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "google/gemma-3-4b-it": {
        "max_input_tokens": 96000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "google/gemma-3-27b-it": {
        "max_input_tokens": 96000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "google/gemini-2.5-pro": {
        "max_input_tokens": 1048576,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": True,
        "pdf_inputs": True,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "google/gemma-3-27b-it:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "z-ai/glm-5": {
        "max_input_tokens": 202752,
        "max_output_tokens": 131000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
    },
    "z-ai/glm-4.5-air": {
        "max_input_tokens": 128000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "z-ai/glm-4.5": {
        "max_input_tokens": 128000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "z-ai/glm-4.6:exacto": {
        "max_input_tokens": 200000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "z-ai/glm-4.7-flash": {
        "max_input_tokens": 200000,
        "max_output_tokens": 65535,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
    },
    "z-ai/glm-4.5-air:free": {
        "max_input_tokens": 128000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
    },
    "z-ai/glm-4.6": {
        "max_input_tokens": 200000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "z-ai/glm-4.7": {
        "max_input_tokens": 204800,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "z-ai/glm-4.5v": {
        "max_input_tokens": 64000,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen3-next-80b-a3b-thinking": {
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen-2.5-vl-7b-instruct:free": {
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen3-32b:free": {
        "max_input_tokens": 40960,
        "max_output_tokens": 40960,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen3-coder:free": {
        "max_input_tokens": 262144,
        "max_output_tokens": 66536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen3-coder-flash": {
        "max_input_tokens": 128000,
        "max_output_tokens": 66536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
        "structured_output": False,
    },
    "qwen/qwen3-30b-a3b:free": {
        "max_input_tokens": 40960,
        "max_output_tokens": 40960,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen3-235b-a22b-07-25:free": {
        "max_input_tokens": 262144,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen3-14b:free": {
        "max_input_tokens": 40960,
        "max_output_tokens": 40960,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen3-coder": {
        "max_input_tokens": 262144,
        "max_output_tokens": 66536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwq-32b:free": {
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen3-coder:exacto": {
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen-2.5-coder-32b-instruct": {
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "qwen/qwen3-30b-a3b-instruct-2507": {
        "max_input_tokens": 262000,
        "max_output_tokens": 262000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen2.5-vl-72b-instruct": {
        "max_input_tokens": 32768,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "qwen/qwen3-coder-30b-a3b-instruct": {
        "max_input_tokens": 160000,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen3-235b-a22b-07-25": {
        "max_input_tokens": 262144,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen3-235b-a22b:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen3-next-80b-a3b-instruct:free": {
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen3-4b:free": {
        "max_input_tokens": 40960,
        "max_output_tokens": 40960,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen3-8b:free": {
        "max_input_tokens": 40960,
        "max_output_tokens": 40960,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen3-30b-a3b-thinking-2507": {
        "max_input_tokens": 262000,
        "max_output_tokens": 262000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen2.5-vl-32b-instruct:free": {
        "max_input_tokens": 8192,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": True,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen3-235b-a22b-thinking-2507": {
        "max_input_tokens": 262144,
        "max_output_tokens": 81920,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "qwen/qwen3-next-80b-a3b-instruct": {
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen2.5-vl-72b-instruct:free": {
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "qwen/qwen3-max": {
        "max_input_tokens": 262144,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "x-ai/grok-3": {
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "x-ai/grok-code-fast-1": {
        "max_input_tokens": 256000,
        "max_output_tokens": 10000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "x-ai/grok-4-fast": {
        "max_input_tokens": 2000000,
        "max_output_tokens": 30000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "x-ai/grok-4": {
        "max_input_tokens": 256000,
        "max_output_tokens": 64000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "x-ai/grok-4.1-fast": {
        "max_input_tokens": 2000000,
        "max_output_tokens": 30000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "x-ai/grok-3-mini-beta": {
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "x-ai/grok-3-mini": {
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "x-ai/grok-3-beta": {
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "meta-llama/llama-3.3-70b-instruct:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "meta-llama/llama-4-scout:free": {
        "max_input_tokens": 64000,
        "max_output_tokens": 64000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "meta-llama/llama-3.2-11b-vision-instruct": {
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "meta-llama/llama-3.2-3b-instruct:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "meta-llama/llama-3.1-405b-instruct:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "tngtech/tng-r1t-chimera:free": {
        "max_input_tokens": 163840,
        "max_output_tokens": 163840,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "tngtech/deepseek-r1t2-chimera:free": {
        "max_input_tokens": 163840,
        "max_output_tokens": 163840,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
    },
    "mistralai/devstral-medium-2507": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/devstral-small-2505:free": {
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/mistral-medium-3": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/codestral-2508": {
        "max_input_tokens": 256000,
        "max_output_tokens": 256000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/devstral-2512:free": {
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/mistral-small-3.1-24b-instruct": {
        "max_input_tokens": 128000,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/devstral-small-2505": {
        "max_input_tokens": 128000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/mistral-7b-instruct:free": {
        "max_input_tokens": 32768,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/devstral-2512": {
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/mistral-small-3.2-24b-instruct": {
        "max_input_tokens": 96000,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/mistral-small-3.2-24b-instruct:free": {
        "max_input_tokens": 96000,
        "max_output_tokens": 96000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/devstral-small-2507": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/mistral-nemo:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "mistralai/mistral-medium-3.1": {
        "max_input_tokens": 262144,
        "max_output_tokens": 262144,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "openai/gpt-5-codex": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-5-pro": {
        "max_input_tokens": 400000,
        "max_output_tokens": 272000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-4o-mini": {
        "max_input_tokens": 128000,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "openai/gpt-5.1-codex-max": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
    },
    "openai/gpt-5.2-codex": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
    },
    "openai/gpt-oss-120b:exacto": {
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-5.1": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
    },
    "openai/gpt-5.2-chat": {
        "max_input_tokens": 128000,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
    },
    "openai/gpt-5-chat": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
    },
    "openai/gpt-5.1-chat": {
        "max_input_tokens": 128000,
        "max_output_tokens": 16384,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
    },
    "openai/gpt-5-image": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-oss-120b": {
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-5.1-codex-mini": {
        "max_input_tokens": 400000,
        "max_output_tokens": 100000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
    },
    "openai/gpt-5.2": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-oss-20b:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-4.1": {
        "max_input_tokens": 1047576,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "openai/gpt-5": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/o4-mini": {
        "max_input_tokens": 200000,
        "max_output_tokens": 100000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-4.1-mini": {
        "max_input_tokens": 1047576,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "openai/gpt-oss-safeguard-20b": {
        "max_input_tokens": 131072,
        "max_output_tokens": 65536,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-5.1-codex": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
    },
    "openai/gpt-5.2-pro": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
        "structured_output": True,
    },
    "openai/gpt-5-mini": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-oss-20b": {
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-oss-120b:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 32768,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "openai/gpt-5-nano": {
        "max_input_tokens": 400000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "minimax/minimax-m1": {
        "max_input_tokens": 1000000,
        "max_output_tokens": 40000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "minimax/minimax-01": {
        "max_input_tokens": 1000000,
        "max_output_tokens": 1000000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "minimax/minimax-m2.1": {
        "max_input_tokens": 204800,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "minimax/minimax-m2": {
        "max_input_tokens": 196600,
        "max_output_tokens": 118000,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "minimax/minimax-m2.5": {
        "max_input_tokens": 204800,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "bytedance-seed/seedream-4.5": {
        "max_input_tokens": 4096,
        "max_output_tokens": 4096,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "anthropic/claude-3.7-sonnet": {
        "max_input_tokens": 200000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "anthropic/claude-opus-4.1": {
        "max_input_tokens": 200000,
        "max_output_tokens": 32000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "anthropic/claude-haiku-4.5": {
        "max_input_tokens": 200000,
        "max_output_tokens": 64000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "anthropic/claude-3.5-haiku": {
        "max_input_tokens": 200000,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": True,
    },
    "anthropic/claude-opus-4.5": {
        "max_input_tokens": 200000,
        "max_output_tokens": 32000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "anthropic/claude-opus-4": {
        "max_input_tokens": 200000,
        "max_output_tokens": 32000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "anthropic/claude-sonnet-4": {
        "max_input_tokens": 200000,
        "max_output_tokens": 64000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "anthropic/claude-sonnet-4.5": {
        "max_input_tokens": 1000000,
        "max_output_tokens": 64000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "anthropic/claude-opus-4.6": {
        "max_input_tokens": 1000000,
        "max_output_tokens": 128000,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "pdf_inputs": True,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "black-forest-labs/flux.2-pro": {
        "max_input_tokens": 46864,
        "max_output_tokens": 46864,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "black-forest-labs/flux.2-flex": {
        "max_input_tokens": 67344,
        "max_output_tokens": 67344,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "black-forest-labs/flux.2-max": {
        "max_input_tokens": 46864,
        "max_output_tokens": 46864,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "black-forest-labs/flux.2-klein-4b": {
        "max_input_tokens": 40960,
        "max_output_tokens": 40960,
        "text_inputs": True,
        "image_inputs": True,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": True,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": False,
        "tool_calling": False,
    },
    "nousresearch/hermes-4-405b": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "nousresearch/hermes-4-70b": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "nousresearch/deephermes-3-llama-3-8b-preview": {
        "max_input_tokens": 131072,
        "max_output_tokens": 8192,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": True,
    },
    "nousresearch/hermes-3-llama-3.1-405b:free": {
        "max_input_tokens": 131072,
        "max_output_tokens": 131072,
        "text_inputs": True,
        "image_inputs": False,
        "audio_inputs": False,
        "video_inputs": False,
        "text_outputs": True,
        "image_outputs": False,
        "audio_outputs": False,
        "video_outputs": False,
        "reasoning_output": True,
        "tool_calling": False,
    },
}



"""Test `langchain_openrouter` public API surface."""

from langchain_openrouter import __all__

EXPECTED_ALL = [
    "ChatOpenRouter",
]


def test_all_imports() -> None:
    """Verify that __all__ exports match the expected public API."""
    assert sorted(EXPECTED_ALL) == sorted(__all__)



"""Standard integration tests for `ChatOpenRouter`."""

from langchain_core.messages import AIMessage, AIMessageChunk
from langchain_tests.integration_tests import ChatModelIntegrationTests

from langchain_openrouter.chat_models import ChatOpenRouter

MODEL_NAME = "openai/gpt-4o-mini"


class TestChatOpenRouter(ChatModelIntegrationTests):
    """Test `ChatOpenRouter` chat model."""

    @property
    def chat_model_class(self) -> type[ChatOpenRouter]:
        """Return class of chat model being tested."""
        return ChatOpenRouter

    @property
    def chat_model_params(self) -> dict:
        """Parameters to create chat model instance for testing."""
        return {
            "model": MODEL_NAME,
            "temperature": 0,
        }

    @property
    def returns_usage_metadata(self) -> bool:
        # Don't want to implement tests for now
        return False

    @property
    def supports_json_mode(self) -> bool:
        return False

    @property
    def supports_image_inputs(self) -> bool:
        return True

    @property
    def supports_image_urls(self) -> bool:
        return True

    @property
    def supports_video_inputs(self) -> bool:
        return True

    @property
    def model_override_value(self) -> str:
        return "openai/gpt-4o"


AUDIO_MODEL = "google/gemini-2.5-flash"
REASONING_MODEL = "openai/o3-mini"


class TestChatOpenRouterMultiModal(ChatModelIntegrationTests):
    """Tests for audio input and reasoning output capabilities.

    Uses an audio-capable model as the base and creates separate model
    instances for reasoning tests.
    """

    @property
    def chat_model_class(self) -> type[ChatOpenRouter]:
        return ChatOpenRouter

    @property
    def chat_model_params(self) -> dict:
        return {
            "model": AUDIO_MODEL,
            "temperature": 0,
        }

    @property
    def returns_usage_metadata(self) -> bool:
        # Don't want to implement tests for now
        return False

    @property
    def supports_json_mode(self) -> bool:
        return False

    @property
    def supports_image_inputs(self) -> bool:
        return True

    @property
    def supports_image_urls(self) -> bool:
        return True

    @property
    def supports_audio_inputs(self) -> bool:
        return True

    @property
    def supports_video_inputs(self) -> bool:
        return True

    @property
    def model_override_value(self) -> str:
        return "openai/gpt-4o"

    def invoke_with_reasoning_output(self, *, stream: bool = False) -> AIMessage:
        """Invoke a reasoning model to exercise reasoning token tracking."""
        llm = ChatOpenRouter(
            model=REASONING_MODEL,
            reasoning={"effort": "medium"},
        )
        prompt = (
            "Explain the relationship between the 2008/9 economic crisis and "
            "the startup ecosystem in the early 2010s"
        )
        if stream:
            full: AIMessageChunk | None = None
            for chunk in llm.stream(prompt):
                full = chunk if full is None else full + chunk  # type: ignore[assignment]
            assert full is not None
            return full
        return llm.invoke(prompt)
